@@ -22,7 +22,7 @@ def _file(string):
 class TestSimpleLoad(unittest.TestCase):
 
     def test_load_post_list(self):
-        post_list = load_post_list('test/simple/')
+        post_list = load_post_list('test/simple/', 'ascii', '')
         self.assertEqual(len(post_list), 3)
         sorted_list = sorted(post_list)
         self.assertEqual(sorted_list[0].title, 'post1')
@@ -30,12 +30,11 @@ class TestSimpleLoad(unittest.TestCase):
         self.assertEqual(sorted_list[2].title, 'post3')
 
     def test_load_post_list_encoding_failure(self):
-        Post.DEFAULT_ENCODING = 'ascii'
-        self.assertRaises(PostError, load_post_list, 'test/encoding/')
+        self.assertRaises(PostError, load_post_list, 'test/encoding/', 'ascii',
+                          '')
 
     def test_load_post_list_encoding(self):
-        Post.DEFAULT_ENCODING = 'UTF-8'
-        post_list = load_post_list('test/encoding/')
+        post_list = load_post_list('test/encoding/', 'UTF-8', '')
         self.assertEqual(len(post_list), 2)
         sorted_list = sorted(post_list)
         self.assertEqual(sorted_list[0].title,
@@ -102,6 +101,25 @@ class TestPost(unittest.TestCase):
             self.failUnless(False) # Should not be there
         self.assertRaises(PostError, Post, _file(sample_post))
 
+    def test_empty_author(self):
+        post = Post(_file('title: test\n\ntest'))
+        self.assertEqual(post.author, u'')
+        self.assertEqual(post.author.name(), u'')
+        self.assertEqual(post.author.email(), u'')
+
+    def test_default_author(self):
+        post = Post(_file('title: test\n\ntest'),
+                    default_author=u'Test <test@test.org>')
+        self.assertEqual(post.author, u'Test <test@test.org>')
+        self.assertEqual(post.author.name(), u'Test')
+        self.assertEqual(post.author.email(), u'test@test.org')
+
+    def test_author(self):
+        post = Post(_file('title:test\nauthor: Test <test@test.org>\n\ntest'))
+        self.assertEqual(post.author, u'Test <test@test.org>')
+        self.assertEqual(post.author.name(), u'Test')
+        self.assertEqual(post.author.email(), u'test@test.org')
+
     def test_bad_date(self):
         sample_post = 'title: bad encoding\ndate: 20 bad date 08-1-1\n\ntest'
         try:
@@ -219,6 +237,9 @@ class TestGeneration(unittest.TestCase):
     def test_publish_simple(self):
         self._test_publish('simple')
 
+    def test_publish_template_encoding(self):
+        self._test_publish('template_encoding')
+
 
 class TestConfiguration(unittest.TestCase):
 
