@@ -73,11 +73,12 @@ class Author(unicode):
 
 class Post(object):
 
-    DEFAULT_ENCODING = u'UTF-8'
-    DEFAULT_AUTHOR = ''
-    FILESYSTEM_ENCODING = locale.getpreferredencoding()
-
-    def __init__(self, f, markup=None):
+    def __init__(self, f,
+                 markup=None,
+                 default_encoding=u'UTF-8',
+                 default_author=u'',
+                 filesystem_encoding=locale.getpreferredencoding()):
+        default_author = Author(default_author)
         if isinstance(f, basestring):
             self._filename = f
             input_file = open(f)
@@ -88,7 +89,7 @@ class Post(object):
 
         # First get the file's encoding
         self.encoding = unicode(post_file.get('encoding') or
-                                self.DEFAULT_ENCODING)
+                                default_encoding)
         try:
             codecs.lookup(self.encoding)
         except LookupError, e:
@@ -103,7 +104,7 @@ class Post(object):
             raise PostError(self.get_filename(), "for key '%s': %s" % (key, e))
 
         if not hasattr(self, 'author'):
-            self.author = self.DEFAULT_AUTHOR
+            self.author = default_author
         else:
             self.author = Author(self.author)
 
@@ -128,7 +129,7 @@ class Post(object):
         if not hasattr(self, 'slug'):
             try:
                 self.slug = self.title.\
-                        encode(self.FILESYSTEM_ENCODING, 'replace').\
+                        encode(filesystem_encoding, 'replace').\
                         replace(' ', '_')
             except UnicodeDecodeError, e:
                 raise PostError(self.get_filename(), 'Bad encoding in title')
